;; Generated package description from devicetree-ts-mode.el  -*- no-byte-compile: t -*-
(define-package "devicetree-ts-mode" "0.3.0.20231222.194823" "Tree-sitter support for DTS" '((emacs "29.1")) :commit "bc07c1124545cbf6e5ebe64e92bfaa306e309033" :authors '(("Aleksandr Vityazev" . "avityazew@gmail.com")) :maintainer '("Aleksandr Vityazev" . "avityazew@gmail.com") :keywords '("languages" "devicetree" "tree-sitter") :url "https://sr.ht/~akagi/devicetree-ts-mode")
